==> haskell-deferred-folds-0.9.18.7-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deferred-folds
version:              0.9.18.7
visibility:           public
id:                   deferred-folds-0.9.18.7-Afy6O1w9Shv3WkvTCuM09r
key:                  deferred-folds-0.9.18.7-Afy6O1w9Shv3WkvTCuM09r
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  8c099a2507e7ac64bbd3ead74612bead
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.7-Afy6O1w9Shv3WkvTCuM09r
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    foldl-1.4.17-hteDtI3XW4BbkGdcyq5s6
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.18.7-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deferred-folds
version:              0.9.18.7
visibility:           public
id:                   deferred-folds-0.9.18.7-Fy3uw6lwtFlGEVWIpPY4CY
key:                  deferred-folds-0.9.18.7-Fy3uw6lwtFlGEVWIpPY4CY
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  4548cc78994414fedd11b725d83bca35
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deferred-folds-0.9.18.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.7-Fy3uw6lwtFlGEVWIpPY4CY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    foldl-1.4.17-KLMSAYYCtxz2sDrVIOcrax
    hashable-1.4.4.0-5O85VrI4oZ4EDBPYdTgwgk
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
